@@ -87,6 +87,16 @@
 #' \code{familyset} are included (or substracted).
 #' @param se Logical; whether standard error(s) of parameter estimates is/are
 #' estimated (default: \code{se = FALSE}).
+#' @param presel Logical; whether to exclude families before fitting based on
+#' symmetry properties of the data. Makes the selection about 30% faster
+#' (on average), but may yield slightly worse results in few special cases.
+#' @param method indicates the estimation method: either maximum
+#' likelihood estimation (\code{method = "mle"}; default) or inversion of
+#' Kendall's tau (\code{method = "itau"}). For \code{method = "itau"} only
+#' one parameter families and the Student t copula can be used (\code{family =
+#' 1,2,3,4,5,6,13,14,16,23,24,26,33,34} or \code{36}). For the t-copula,
+#' \code{par2} is found by a crude profile likelihood optimization over the
+#' interval (2, 10].
 #'
 #' @return An object of class \code{\link{BiCop}}, augmented with the following
 #' entries:
@@ -160,16 +170,20 @@
 #'
 BiCopSelect <- function(u1, u2, familyset = NA, selectioncrit = "AIC",
                         indeptest = FALSE, level = 0.05, weights = NA,
-                        rotations = TRUE, se = FALSE) {
+                        rotations = TRUE, se = FALSE, presel = TRUE,
+                        method = "mle") {
     if (!(selectioncrit %in% c("AIC", "BIC", "logLik")))
         stop("Selection criterion not implemented.")
     ## preprocessing of arguments
+    if (presel)
+        todo_fams <- todo_fams_presel
     args <- preproc(c(as.list(environment()), call = match.call()),
                     check_u,
                     remove_nas,
                     check_nobs,
                     check_if_01,
                     prep_familyset,
+                    check_twoparams,
                     check_est_pars,
                     check_fam_tau,
                     todo_fams,
@@ -191,6 +205,7 @@ BiCopSelect <- function(u1, u2, familyset = NA, selectioncrit = "AIC",
         for (i in seq_along(familyset)) {
             optiout[[i]] <- BiCopEst.intern(u1, u2,
                                             family = familyset[i],
+                                            method = method,
                                             se = se,
                                             weights = weights,
                                             as.BiCop = FALSE)
